@@ -253,22 +253,22 @@ bool TimingWidget::getOptions( )
 	uint    scanDelayValue      = m_scanDelayLineEdit->text( ).toUInt( );
 
 	if( minHostGroupValue > maxHostGroupValue )
-	{	KMessageBox::error( this, i18n( TQString( "Min host group not < Max host group" )), i18n( "Host group error" ));
+	{	KMessageBox::error( this, i18n( "Min host group not < Max host group" ), i18n( "Host group error" ));
 		return false;
 	}
 
 	if( minParallelismValue > maxParallelismValue )
-	{	KMessageBox::error( this, i18n( TQString( "Min parallelism not < Max parallelism" )), i18n( "Parallelism error" ));
+	{	KMessageBox::error( this, i18n( "Min parallelism not < Max parallelism" ), i18n( "Parallelism error" ));
 		return false;
 	}
 
 	if( minRTTTimeoutValue > maxRTTTimeoutValue )
-	{	KMessageBox::error( this, i18n( TQString( "Min RTT timeout not < Max RTT timeout" )), i18n( "RTT timeout error" ));
+	{	KMessageBox::error( this, i18n( "Min RTT timeout not < Max RTT timeout" ), i18n( "RTT timeout error" ));
 		return false;
 	}
 
 	if( scanDelayValue > maxScanDelayValue )
-	{	KMessageBox::error( this, i18n( TQString( "Min scan delay not < Max scan delay" )), i18n( "Scan delay error" ));
+	{	KMessageBox::error( this, i18n( "Min scan delay not < Max scan delay" ), i18n( "Scan delay error" ));
 		return false;
 	}
 
@@ -397,7 +397,7 @@ void TimingWidget::setInitialValues( )
 
 		default:
 			kdDebug( ) << "internal error - unknown simple timing value " << m_simpleTimingValue << endl;
-			ASSERT( false );
+			Q_ASSERT( false );
 	}
 }
 
@@ -416,7 +416,7 @@ TQString TimingWidget::simpleTiming( ) const
 	}
 
 	kdDebug( ) << "internal error - unknown simple timing value " << m_simpleTimingValue << endl;
-	ASSERT( false );
+	Q_ASSERT( false );
 	return TQString::null;
 }
 
@@ -662,3 +662,5 @@ void TimingWidget::slotWhatsThisClicked( )
 	else if( m_sneakyRadio->hasMouse( ))               emit( displayHelp( "-T"                    ));
 	else emit( displayUnknown( ));
 }
+
+#include "timingwidget.moc"
